﻿/**
 * Copyright (c) 2006, Opera Software ASA
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Opera Software ASA nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY OPERA SOFTWARE ASA AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL OPERA SOFTWARE ASA AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Checks if the element has a given CSS class
 * @param {String} c Class to check for
 * @return True if the element has the class
 * @type Boolean
 */
HTMLElement.prototype.hasClass = function(c) {
	return (" " + this.className + " ").indexOf(" " + c + " ") != -1;
}
/**
 * Adds a CSS class to the element
 * @param {String} c Class to add
 * @return True if the class was added, false if element already had the class
 * @type Boolean
 */
HTMLElement.prototype.addClass = function(c) {
	if (!this.hasClass(c)) {
		this.className = this.className + " " + c;
		return true;
	}
	return false;
}
/**
 * Removes a CSS class from the element
 * @param {String} c Class to remove
 * @return True if the class was removed, flase if element didn't have the class
 * @type Boolean
 */
HTMLElement.prototype.dropClass = function(c) {
	if (this.hasClass(c)) {
		this.className = (" " + this.className + " ").replace(" " + c + " ", " ");
		return true;
	}
	return false;
}
